# **Vulcan notation**

# Exemplar and Guideline

# Category and annotation

A category is a tree-based structural description of the annotations. In an informal vernacular, it describes all possible ways that users can answer. Users must provide annotation answers that strictly obey the structure imposed by the category tree.
